package client

import (
	"encoding/json"
	"errors"
	"git.selly.red/Selly-Modules/natsio"
	"git.selly.red/Selly-Modules/natsio/model"
	"git.selly.red/Selly-Modules/natsio/subject"
	"go.mongodb.org/mongo-driver/bson"
)

// AuthSMS ...
type AuthSMS struct{}

// GetAutSMS ...
func GetAutSMS() AuthSMS {
	return AuthSMS{}
}

func (s AuthSMS) CreateUserSMSViaAuthSMS(p model.CreateUserSMSRequest) (*model.CreateUserSMSResponse, error) {
	msg, err := natsio.GetServer().Request(subject.AuthSMS.CreateUserSMS, toBytes(p))
	if err != nil {
		return nil, err
	}

	var r struct {
		Data  *model.CreateUserSMSResponse `json:"data"`
		Error string                       `json:"error"`
	}

	if err = json.Unmarshal(msg.Data, &r); err != nil {
		return nil, err
	}
	if r.Error != "" {
		return nil, errors.New(r.Error)
	}

	return r.Data, nil
}

func (s AuthSMS) GetListPermission() (*model.GetListPermissionResponse, error) {
	msg, err := natsio.GetServer().Request(subject.AuthSMS.GetListPermission, toBytes(bson.M{}))
	if err != nil {
		return nil, err
	}

	var r struct {
		Data  *model.GetListPermissionResponse `json:"data"`
		Error string                           `json:"error"`
	}

	if err = json.Unmarshal(msg.Data, &r); err != nil {
		return nil, err
	}
	if r.Error != "" {
		return nil, errors.New(r.Error)
	}

	return r.Data, nil
}
